pub struct AudioCapture { /* private fields */ }Expand description
Audio capture stream that reads from a microphone.
Implementations
Sourceimpl AudioCapture
impl AudioCapture
Sourcepub fn start(
selector: &DeviceSelector,
config: &AudioConfig,
) -> Result<Self, String>
pub fn start( selector: &DeviceSelector, config: &AudioConfig, ) -> Result<Self, String>
Start capturing audio from the selected input device.
If the device doesn’t support the requested sample rate, we find the nearest supported rate and downsample in the capture callback.
Sourcepub async fn next_frame(&mut self) -> Option<Vec<i16>>
pub async fn next_frame(&mut self) -> Option<Vec<i16>>
Receive the next audio frame.