AudioPlayback

Struct AudioPlayback 

pub struct AudioPlayback { /* private fields */ }
Audio playback stream that writes to a speaker.

Implementations

Source

impl AudioPlayback

pub fn start( selector: &DeviceSelector, config: &AudioConfig, ) -> Result<Self, String>

Start playing audio on the selected output device.

If the device doesn’t support the requested sample rate, we find the nearest supported rate and perform linear interpolation resampling in the playback callback.

pub async fn play_frame(&self, frame: Vec<i16>) -> Result<(), String>

Send an audio frame for playback.