pub struct AudioPlayback { /* private fields */ }Expand description
Audio playback stream that writes to a speaker.
Implementations
Sourceimpl AudioPlayback
impl AudioPlayback
Sourcepub fn start(
selector: &DeviceSelector,
config: &AudioConfig,
) -> Result<Self, String>
pub fn start( selector: &DeviceSelector, config: &AudioConfig, ) -> Result<Self, String>
Start playing audio on the selected output device.
If the device doesn’t support the requested sample rate, we find the nearest supported rate and perform linear interpolation resampling in the playback callback.